@@ -174,8 +174,10 @@ general_next_pressed_cb (GnomeDruidPage *druid_page,
 			 GtkWidget *druid_widget,
 			 gpointer user_data)
 {
+	GdaDataSourceInfo *dsn_info;
 	GdaProviderInfo *prov_info;
 	GList *l;
+	gint i;
 	const gchar *name;
 	const gchar *provider;
 	GnomeDbDsnConfigDruid *druid = (GnomeDbDsnConfigDruid *) user_data;
@@ -190,6 +192,26 @@ general_next_pressed_cb (GnomeDruidPage *druid_page,
 		return TRUE;
 	}
 
+	dsn_info = gnome_db_config_find_data_source (name);
+	if (dsn_info != NULL) {
+		gnome_db_config_free_data_source_info (dsn_info);
+		gnome_db_show_error (_("An existing data source is already registered under the same name"));
+		gtk_widget_grab_focus (druid->priv->general_name);
+		return TRUE;
+	}
+
+	for (i = 0; i < strlen (name); i++) {
+		if (g_ascii_isspace (name[i])) {
+			gnome_db_show_error (_("Data source names cannot contain spaces"));
+			gtk_widget_grab_focus (druid->priv->general_name);
+			return TRUE;
+		} else if (!g_ascii_isalnum (name[i])) {
+			gnome_db_show_error (_("Data source names can only contain ASCII letters and numbers"));
+			gtk_widget_grab_focus (druid->priv->general_name);
+			return TRUE;
+		}
+	}
+
 	provider = gnome_db_option_menu_get_selection (GTK_OPTION_MENU (druid->priv->general_provider));
 	if (!provider) {
 		gnome_db_show_error (_("You must select a provider for the new data source"));
