@@ -381,6 +381,9 @@ gnome_db_new_table_widget (gint rows, gint cols, gboolean homogenous)
 	GtkWidget *table;
 
 	table = gtk_table_new (rows, cols, homogenous);
+	gtk_table_set_row_spacings (GTK_TABLE (table), 6);
+        gtk_table_set_col_spacings (GTK_TABLE (table), 6);
+
 	gtk_widget_show (table);
 
 	return table;
@@ -515,14 +518,14 @@ gnome_db_set_widget_fg_color (GtkWidget *widget, const gchar *color)
 /**
  * gnome_db_option_menu_add_item
  */
-void
+GtkWidget *
 gnome_db_option_menu_add_item (GtkOptionMenu *option_menu, const gchar *label)
 {
 	GtkWidget *menu;
 	GtkWidget *menu_item;
 
-	g_return_if_fail (GTK_IS_OPTION_MENU (option_menu));
-	g_return_if_fail (label != NULL);
+	g_return_val_if_fail (GTK_IS_OPTION_MENU (option_menu), NULL);
+	g_return_val_if_fail (label != NULL, NULL);
 
 	menu = gtk_option_menu_get_menu (option_menu);
 	if (!GTK_IS_MENU (menu)) {
@@ -537,6 +540,61 @@ gnome_db_option_menu_add_item (GtkOptionMenu *option_menu, const gchar *label)
 				g_strdup (label), (GDestroyNotify) g_free);
 
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
+
+	return menu_item;
+}
+
+/**
+ * gnome_db_option_menu_add_stock_item
+ */
+GtkWidget *
+gnome_db_option_menu_add_stock_item (GtkOptionMenu *option_menu, const gchar *stock_id)
+{
+	GtkWidget *menu;
+	GtkWidget *menu_item;
+
+	g_return_val_if_fail (GTK_IS_OPTION_MENU (option_menu), NULL);
+	g_return_val_if_fail (stock_id != NULL, NULL);
+
+	menu = gtk_option_menu_get_menu (option_menu);
+	if (!GTK_IS_MENU (menu)) {
+		menu = gtk_menu_new ();
+		gtk_option_menu_set_menu (option_menu, menu);
+		gtk_widget_show (menu);
+	}
+
+	menu_item = gtk_image_menu_item_new_from_stock (stock_id, NULL);
+	gtk_widget_show (menu_item);
+	g_object_set_data_full (G_OBJECT (menu_item), "GNOME:Database:MenuItemLabel",
+				g_strdup (stock_id), (GDestroyNotify) g_free);
+
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
+
+	return menu_item;
+}
+
+/**
+ * gnome_db_option_menu_add_separator
+ */
+void
+gnome_db_option_menu_add_separator (GtkOptionMenu *option_menu)
+{
+	GtkWidget *menu;
+	GtkWidget *menu_item;
+
+	g_return_if_fail (GTK_IS_OPTION_MENU (option_menu));
+
+	menu = gtk_option_menu_get_menu (option_menu);
+	if (!GTK_IS_MENU (menu)) {
+		menu = gtk_menu_new ();
+		gtk_option_menu_set_menu (option_menu, menu);
+		gtk_widget_show (menu);
+	}
+
+	menu_item = gtk_separator_menu_item_new ();
+	gtk_widget_show (menu_item);
+
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
 }
 
 /**
@@ -750,6 +808,7 @@ gnome_db_yes_no_dialog (GtkWidget *parent, const gchar *format, ...)
 	va_list args;
         gchar sz[2048];
 	GtkWidget *dialog;
+	GdkPixbuf *icon;
 	gboolean retval = FALSE;
 
 	/* build the message string */
@@ -762,8 +821,12 @@ gnome_db_yes_no_dialog (GtkWidget *parent, const gchar *format, ...)
 					 GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION,
 					 GTK_BUTTONS_YES_NO, sz);
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Question"));
-	gtk_window_set_icon_from_file (GTK_WINDOW (dialog),
-					 LIBGNOMEDB_ICONSDIR "/gnome-db.png", NULL);
+
+	icon = gdk_pixbuf_new_from_file (LIBGNOMEDB_ICONSDIR "/gnome-db.png", NULL);
+	if (icon) {
+		gtk_window_set_icon (GTK_WINDOW (dialog), icon);
+		g_object_unref (icon);
+	}
 
 	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES)
 		retval = TRUE;
