@@ -30,17 +30,23 @@
 #include <gtk/gtktoolbar.h>
 #include <gtk/gtktreemodel.h>
 #include <gtk/gtkwidget.h>
+#ifdef BUILD_WITH_GNOME
 #include <libgnomeui/gnome-popup-menu.h>
+#endif
 
 G_BEGIN_DECLS
 
+#ifdef BUILD_WITH_GNOME
 GtkWidget   *gnome_db_new_browser_widget (void);
+#endif
 GtkWidget   *gnome_db_new_button_widget (const gchar *label);
 GtkWidget   *gnome_db_new_button_widget_from_stock (const gchar *stock_id);
 GtkWidget   *gnome_db_new_check_button_widget (const gchar *label);
 GtkWidget   *gnome_db_new_combo_widget (void);
 GtkWidget   *gnome_db_new_entry_widget (gint max_length, gboolean editable);
+#ifdef BUILD_WITH_GNOME
 GtkWidget   *gnome_db_new_file_entry_widget (const gchar *history_id, const gchar *title);
+#endif
 GtkWidget   *gnome_db_new_frame_widget (const gchar *title);
 GtkWidget   *gnome_db_new_grid_widget (GdaDataModel *model);
 GtkWidget   *gnome_db_new_hbox_widget (gboolean homogenous, gint spacing);
@@ -50,9 +56,11 @@ GtkWidget   *gnome_db_new_hseparator_widget (void);
 GtkWidget   *gnome_db_new_label_widget (const gchar *text);
 GtkWidget   *gnome_db_new_notebook_widget (void);
 GtkWidget   *gnome_db_new_option_menu_widget (void);
+#ifdef BUILD_WITH_GNOME
 GtkWidget   *gnome_db_new_popup_menu (GtkWidget *parent,
 				      GnomeUIInfo *ui_info,
 				      gpointer user_data);
+#endif
 GtkWidget   *gnome_db_new_radio_button_widget (GSList *group, const gchar *label);
 GtkWidget   *gnome_db_new_scrolled_window_widget (void);
 GtkWidget   *gnome_db_new_status_bar_widget (void);
@@ -67,7 +75,9 @@ GtkWidget   *gnome_db_new_vseparator_widget (void);
 void         gnome_db_set_widget_bg_color (GtkWidget *widget, const gchar *color);
 void         gnome_db_set_widget_fg_color (GtkWidget *widget, const gchar *color);
 
-void         gnome_db_option_menu_add_item (GtkOptionMenu *option_menu, const gchar *label);
+GtkWidget   *gnome_db_option_menu_add_item (GtkOptionMenu *option_menu, const gchar *label);
+GtkWidget   *gnome_db_option_menu_add_stock_item (GtkOptionMenu *option_menu, const gchar *stock_id);
+void         gnome_db_option_menu_add_separator (GtkOptionMenu *option_menu);
 const gchar *gnome_db_option_menu_get_selection (GtkOptionMenu *option_menu);
 void         gnome_db_option_menu_set_selection (GtkOptionMenu *option_menu,
 						 const gchar *selection);
@@ -87,6 +97,9 @@ gboolean     gnome_db_yes_no_dialog (GtkWidget *parent, const gchar *format, ...
 void         gnome_db_show_error (const gchar *format, ...);
 void         gnome_db_show_message (const gchar *format, ...);
 
+void         gnome_db_push_cursor_busy (GtkWidget *window);
+void         gnome_db_pop_cursor_busy (GtkWidget *window);
+
 G_END_DECLS
 
 #endif
